#ifndef NT2_INCLUDE_FUNCTIONS_LOGSPACE_ADD_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_LOGSPACE_ADD_HPP_INCLUDED

#include <nt2/exponential/include/functions/logspace_add.hpp>

#endif
